Module blaxel.models.memory_allocation_metric
=============================================

Classes
-------

`MemoryAllocationMetric(total_allocation: blaxel.types.Unset | float = <blaxel.types.Unset object>)`
:   Metrics for memory allocation
    
    Attributes:
        total_allocation (Union[Unset, float]): Total memory allocation in GB-seconds
    
    Method generated by attrs for class MemoryAllocationMetric.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `total_allocation: blaxel.types.Unset | float`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :